<template>
	<div class="w-full space-y-3">
		<template v-if="parsedData && parsedData.length > 0">
			<template v-for="(item, index) in parsedData" :key="item.id">
				<!-- <el-button type="primary" v-if="showReportIndex.includes(index) && conclusion.length > 0" @click="showAgentReport(index)">报告</el-button> -->
				<component
					ref="componentRef"
					:id="item.id"
					:is="summaryAnswerTypeMapCom[item.type]"
					:data="item"
					:originData="originData"
					:reportIndex="reportIndex"
					:summaryIndex="index"
					chartHeight="20rem"
					:tableLimitHeight="tableLimitHeight"
					:historyId="historyId"
					@updateQuery="(res) => updateRecordSet(index, res)"
					:disabled="isTalking || isSharePage"
				></component>

				<div class="flex flex-col" v-if="showReportIndex.includes(index) && conclusion?.length > 0">
					<div class="flex items-center mb-3">
						<span class="mr-2">分析评估：</span>
						<div
							@click="toggleReport(item)"
							class="cursor-pointer border border-gray-300 border-solid w-fit px-2 flex items-center space-x-2 rounded-lg hover:bg-gray-100 active:bg-gray-200"
						>
							<span>
								{{ toggleReportLabel(item) }}
							</span>
							<span class="ywifont" :class="{ 'ywicon-unfold': !item.reportIsShow, 'ywicon-fold': item.reportIsShow }"></span>
						</div>
					</div>

					<!-- 过程输出 -->
					<div v-show="item.reportIsShow" class="max-h-[2/3vh] markdown-it" v-html="md.render(getReport(index))"></div>
				</div>
			</template>
		</template>
		<el-empty v-else :image-size="200" class="!py-3">
			<!-- <template #description>
				<span > 暂无数据 </span>
			</template> -->
		</el-empty>
		<!-- <ReportDlg v-model="infoDlgIsShow" :report="report" :agentKey="agentKey"></ReportDlg> -->
	</div>
</template>

<script setup lang="ts">
import { computed, ref } from 'vue';
import { chatComProps } from '../common';
import { SummaryAnswerType, summaryAnswerTypeMapCom } from './components/types';
// import AmisPageTest from './components/amisPage/AmisPageTest.vue';

import ReportDlg from './ReportDlg.vue';
import { md } from '../../libs/markdown';
import { isSharePage } from '/@/stores/chatRoom';
import service from '/@/utils/request';
const props = defineProps(chatComProps);
const tableLimitHeight = document.body.clientHeight * 0.7;
const parsedData = computed<any[]>(() => {
	const newData = (props.data ?? []).map((item) => {
		if (item.type === SummaryAnswerType.RecordSet && item.chart === 'table') {
			item.type = SummaryAnswerType.RecordSetTable;
		}
		return item;
	});
	return newData;
});

// 需要展示 report 的 索引
const showReportIndex = computed(() => {
	const agentKeyMap = new Map<string, number>();
	parsedData.value.forEach((value, index) => {
		if (value?.agent_key) {
			// 取最后一次作为结论
			agentKeyMap.set(value.agent_key, index);
			// if (!agentKeySet.has(value.agent_key)) {
			// 	agentKeySet.add(value.agent_key);
			// 	indexList.push(index);
			// }
		}
	});
	const indexList = Array.from(agentKeyMap.values());

	return indexList;
});

const componentRef = ref<any[]>(null);

const updateRecordSet = (triggerIndex, res) => {
	for (const item of componentRef.value) {
		item?.updateAll(triggerIndex, res);
	}
};

const getReport = (agentEndIndex) => {
	const agent = parsedData.value[agentEndIndex];
	const agentKey = agent.agent_key;
	// debugger;
	const foundReport = props.conclusion.find((item) => item.agent_key === agentKey);
	const report = foundReport?.report ?? '';
	return report;
};

const toggleReportLabel = (item) => (item.reportIsShow ? '收起' : '展开');
const toggleReport = (item) => {
	item.reportIsShow = !item.reportIsShow;
};
// const infoDlgIsShow = ref(false);
// const report = ref(null);

// const agentKey = ref('');

// const conclusion = computed(() => props.originData?.content?.origin?.conclusion ?? []);
// const showAgentReport = (agentStartIndex) => {
// 	const agent = parsedData.value[agentStartIndex];
// 	agentKey.value = agent.agent_key;
// 	const foundReport = conclusion.value.find((item) => item.agent_key === agentKey.value);
// 	report.value = foundReport?.report;

// 	infoDlgIsShow.value = true;
// };


</script>
<style scoped lang="scss"></style>
